==> download.php?d=bsmyjspace_pack_2.6.0_PACK.zip: admin/sql/install/install.sqlazure.utf8.sql <==
/* -- install.sqlazure.utf8.sql */
/* -- version 2.6.0 28/04/2016 */
/* -- author	Bernard saulme */
/* -- package	com_myjspace */

/* -- AFAIRE Ajouter 'IF NOT EXISTS' pour la table ? */

SET QUOTED_IDENTIFIER ON;

CREATE TABLE [#__myjspace] (
	[id] [bigint] IDENTITY(1,1) NOT NULL,
	[title] [nvarchar](100) NOT NULL DEFAULT '',
	[pagename] [nvarchar](100) NOT NULL,
	[foldername] [nvarchar](150) NOT NULL DEFAULT 'myjsp',
	[userid] [int] NOT NULL DEFAULT 0,
	[modified_by] [bigint] NOT NULL DEFAULT 0,
    [access] [bigint] NOT NULL DEFAULT 0,
	[content] [nvarchar](max) NULL,
	[blockEdit] [smallint] NOT NULL DEFAULT 0,
	[blockView] [bigint] NOT NULL DEFAULT 1,
	[userread] [nvarchar](100) NOT NULL DEFAULT '',
	[create_date] [datetime] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
	[last_update_date] [datetime],
	[last_access_date] [datetime],
	[last_access_ip] [nvarchar](8) NOT NULL DEFAULT '0',
	[hits] [bigint] NOT NULL DEFAULT 0,   
    [publish_up] [datetime] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
    [publish_down] [datetime] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
	[metakey] [nvarchar](max) NOT NULL DEFAULT '',
	[template] [nvarchar](50) NOT NULL DEFAULT '',
	[catid] [int] NOT NULL DEFAULT 0,
	[language] [nvarchar](7) NOT NULL DEFAULT '*',
 CONSTRAINT [PK_#__myjspace_id] PRIMARY KEY CLUSTERED
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY];

CREATE NONCLUSTERED INDEX [idx_pagename] ON [#__myjspace]
(
	[pagename] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);

CREATE NONCLUSTERED INDEX [idx_userid] ON [#__myjspace]
(
	[userid] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);

CREATE NONCLUSTERED INDEX [idx_access] ON [#__myjspace]
(
	[access] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);

==> download.php?d=bsmyjspace_pack_2.6.4_PACK.zip: admin/sql/install/install.sqlazure.utf8.sql <==
/* -- install.sqlazure.utf8.sql */
/* -- version 2.6.2 07/04/2017 */
/* -- author	Bernard saulme */
/* -- package	com_myjspace */

/* -- AFAIRE Ajouter 'IF NOT EXISTS' pour la table ? */

SET QUOTED_IDENTIFIER ON;

CREATE TABLE [#__myjspace] (
	[id] [bigint] IDENTITY(1,1) NOT NULL,
	[title] [nvarchar](100) NOT NULL DEFAULT '',
	[pagename] [nvarchar](100) NOT NULL,
	[foldername] [nvarchar](150) NOT NULL DEFAULT 'myjsp',
	[userid] [int] NOT NULL DEFAULT 0,
	[modified_by] [bigint] NOT NULL DEFAULT 0,
    [access] [bigint] NOT NULL DEFAULT 0,
	[content] [nvarchar](max) NULL,
	[blockEdit] [smallint] NOT NULL DEFAULT 0,
	[blockView] [bigint] NOT NULL DEFAULT 1,
	[userread] [nvarchar](100) NOT NULL DEFAULT '',
	[create_date] [datetime2(0)] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
	[last_update_date] [datetime2(0)],
	[last_access_date] [datetime2(0)],
	[last_access_ip] [nvarchar](8) NOT NULL DEFAULT '0',
	[hits] [bigint] NOT NULL DEFAULT 0,   
    [publish_up] [datetime2(0)] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
    [publish_down] [datetime2(0)] NOT NULL DEFAULT '1900-01-01T00:00:00.000',
	[metakey] [nvarchar](max) NOT NULL DEFAULT '',
	[template] [nvarchar](50) NOT NULL DEFAULT '',
	[catid] [int] NOT NULL DEFAULT 0,
	[language] [nvarchar](7) NOT NULL DEFAULT '*',
 CONSTRAINT [PK_#__myjspace_id] PRIMARY KEY CLUSTERED
(
	[id] ASC
)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
) ON [PRIMARY];

CREATE NONCLUSTERED INDEX [idx_pagename] ON [#__myjspace]
(
	[pagename] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);

CREATE NONCLUSTERED INDEX [idx_userid] ON [#__myjspace]
(
	[userid] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);

CREATE NONCLUSTERED INDEX [idx_access] ON [#__myjspace]
(
	[access] ASC
)WITH (STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, DROP_EXISTING = OFF, ONLINE = OFF);
